@@ -4,7 +4,8 @@ use is31fl3731::devices::CharlieBonnet;
 use rppal::{hal, i2c::I2c};
 
 fn main() {
-    let mut ic = CharlieBonnet::configure(I2c::new().expect("Failed to load i2c bus"), hal::Delay);
+    let mut delay = hal::Delay;
+    let mut ic = CharlieBonnet::configure(I2c::new().expect("Failed to load i2c bus"), &mut delay);
     ic.setup().expect("Failed to setup IC");
 
     for x in 0..16 {
